<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

/**
 * @OA\RequestBody(
 *   request="ServerHeartbeat",
 *   required=true,
 *   @OA\JsonContent(
 *     required={"ip", "port", "pubkey"},
 *     @OA\Property(
 *       property="ip",
 *       type="string",
 *        format="ip",
 *       description="IP of the server",
 *     ),
 *         @OA\Property(
 *       property="port",
 *       type="integer",
 *       description="Port of the server",
 *     ),
 *     @OA\Property(
 *       property="pubkey",
 *       type="string",
 *       description="Public RSA key of the server",
 *       format="PEM Publick Key",
 *       pattern="^-----BEGIN PUBLIC KEY-----(\n|\r|\r\n)([0-9a-zA-Z\+\/=]{64}(\n|\r|\r\n))*([0-9a-zA-Z\+\/=]{1,63}(\n|\r|\r\n))?-----END PUBLIC KEY-----$"
 *     ),
 *   ),
 * ),
 */
class ServerHeartbeatRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        return [
            'ip' => 'required|ip',
            'port' => 'required|integer|numeric',
            'pubkey' => ['required', 'string', 'max:1024', 'regex:/^-----BEGIN PUBLIC KEY-----(\n|\r|\r\n)([0-9a-zA-Z\+\/=]{64}(\n|\r|\r\n))*([0-9a-zA-Z\+\/=]{1,63}(\n|\r|\r\n))?-----END PUBLIC KEY-----$/']
        ];
    }
}
