<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Support\Facades\Auth;
use Illuminate\Validation\Rule;

/**
 * @OA\RequestBody(
 *   request="UpdateProfile",
 *   required=true,
 *   @OA\JsonContent(
 *     @OA\Property(
 *       property="username",
 *       type="string",
 *       description="Username of the user",
 *     ),
 *     @OA\Property(
 *       property="email",
 *       type="string",
 *       format="email",
 *       description="Email of the user",
 *     ),
 *     @OA\Property(
 *       property="password",
 *       type="string",
 *       description="Password of the user",
 *     ),
 *   ),
 * ),
 */
class UpdateProfileRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        return [
            'username' => ['sometimes', 'required', 'string', 'max:255', Rule::unique('users')->ignore(Auth::user()->id)],
            'email' => ['sometimes', 'required',' string',' email',' max:255', Rule::unique('users')->ignore(Auth::user()->id)],
            'password' => 'sometimes|required|string|min:6',
        ];
    }
}
