<?php

namespace Tests\Feature;

use App\Models\Server;
use App\Models\User;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Foundation\Testing\WithFaker;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Tests\TestCase;

class HeartbeatTest extends TestCase
{
    use RefreshDatabase;

    public function test_good()
    {
        $user = User::create([
            'username' => 'test',
            'email' => 'test@localhost',
            'password' => Hash::make('test'),
        ]);

        $server = Server::create([
            'login' => 'test',
            'password' => Hash::make('test'),
            'owner_id' => $user->id,
            'public' => true
        ]);

        $server_token = Auth::guard('server')->login($server);

        $response = $this->withHeaders([
            "Authorization" => "Bearer " . $server_token
        ])->post('/api/auth/server/heartbeat', [
            'ip' => '127.0.0.1',
            'port' => 12345,
            'pubkey' => '-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAy7IwoHhmFbuVp1vsu9IK
DLenHdy7IPJxMaw2Xq7zbgTZXlYQjNFky9coiyYWMXw2i7g1f3xptKvIKbDuEMvG
ifCwXVRAOHJKehhwVVL7IRRjleb3YGm5m1lLqPdYvfecn20mFdwuk/6Rkg003fKs
JsZiLCgrRknlQbIatiTakBGMu+D3pCwHc1MLEitEVUPBECLM66DBVKo5o1/vWQZF
glfcOB7nQpzyRagFUuRnPhYDSFNma8hkYGQctHpgdFUFq7Oofj8L3wxLM77h2H9s
ib5ctqtHzWneJ9APCB0YQ7dI4enzpeFi16x9/tuJS6jOwt5Is9PEVRtSrw9wKQbP
hvYbZGcPm7okV9ut3c/iJgtqta6dabIXkVTbHXrPtSW8Rs5toykj6DNAcCrvTEgP
dFmzbYJJv6Yfo219MVvEtLY0cC43gwXNMoxykdxBzCY0bihiRefaFK1g+6NR5H4H
KYRcc3SMB3YSkGNnzlSw89WCVvdnlU3hpcK9/M3hSvPsqUBB/uYNG5CMvRTLg1uO
q7BbLlbzqXh6utyQ/92QqYYrRwgQdRTamXRdcrCf3Ni4PZEem03/bfzBbN946Rgp
2wusu+zAWwwPbbigXnzC9VinPw8MLW54NzdnR0cp8b6HToi6Jf9IByb2O/Jf9LOv
RVQXdit0Wzv68t7iQ86vVyMCAwEAAQ==
-----END PUBLIC KEY-----'
        ]);
        $response->assertStatus(204);
    }

    public function test_no_data()
    {
        $user = User::create([
            'username' => 'test',
            'email' => 'test@localhost',
            'password' => Hash::make('test'),
        ]);

        $server = Server::create([
            'login' => 'test',
            'password' => Hash::make('test'),
            'owner_id' => $user->id,
            'public' => true
        ]);

        $server_token = Auth::guard('server')->login($server);

        $response = $this->withHeaders([
            "Authorization" => "Bearer " . $server_token
        ])->post('/api/auth/server/heartbeat', [
        ]);
        $response->assertStatus(422);
    }

    public function test_malformed_key()
    {
        $user = User::create([
            'username' => 'test',
            'email' => 'test@localhost',
            'password' => Hash::make('test'),
        ]);

        $server = Server::create([
            'login' => 'test',
            'password' => Hash::make('test'),
            'owner_id' => $user->id,
            'public' => true
        ]);

        $server_token = Auth::guard('server')->login($server);

        $response = $this->withHeaders([
            "Authorization" => "Bearer " . $server_token
        ])->post('/api/auth/server/heartbeat', [
            'ip' => '127.0.0.1',
            'port' => 12345,
            'pubkey' => 'Lorem ipsum dolor sit amet'
        ]);
        $response->assertStatus(422);
    }
}
